@@ -100,7 +100,7 @@ venues.parseVenue = function(response, page) {
         page.venueTypeUrl = parseIcon(venue.categories[0].icon);
     else
         page.venueTypeUrl = parseIcon(defaultVenueIcon);
-    if(venue.mayor.count>0) {
+    if(venue.mayor && venue.mayor.count>0) {
         page.venueMajorCount = venue.mayor.count;
         page.venueMajor = makeUserName(venue.mayor.user);
         page.venueMajorPhoto = thumbnailPhoto(venue.mayor.user.photo,100);
