@@ -1,6 +1,8 @@
 #ifndef QMLCACHE_H
 #define QMLCACHE_H
 
+#define CACHE_DAY_DURATION 14
+
 #include <QObject>
 #include <QString>
 #include <QVariant>
@@ -20,10 +22,13 @@ protected:
 
     QString m_path;
 
+    // url, localname
     QMap<QString,QString> m_cachemap;
     QReadWriteLock m_cachemap_lock;
 
+    // ids
     typedef QSet<QString> CCallbackList;
+    // url, list of ids
     typedef QMap<QString, CCallbackList > CCacheQueue;
     CCacheQueue m_cachequeue;
     QReadWriteLock m_cachequeue_lock;
@@ -36,6 +41,8 @@ protected:
 
 public:
     explicit Cache(QObject *parent = 0);
+
+    Q_INVOKABLE QVariant getFile(QVariant url);
     
     Q_INVOKABLE void queueObject(QVariant url, QVariant callback);
 
